////////////////////////////////////////////////////////////////////////////////////////
// Name: Physics.cpp 
// Author: DevCNub 
// Last Updated: 07/05/2013 
// 	  
// 
// Notes: - Inheriting from a fundamental Object class is not viable
//          as different Objects will come with radically different 
//		    immutable characteristics. For example, we cannot 
//		    apply the concept of initial acceleration to 
//		    an Object of class Wire, whereas the computations
//		    involving a charge point take this as a given when 
//		    it is required. The drift velocity is another example; 
//			it belongs to the scheme of the charge object. 
//	
//		  - No need to implement Electron as a derived class of PointCharge 
//			(it's assumed that the electron characteristics are known at "user time")
////////////////////////////////////////////////////////////////////////////////////////


#ifndef PHYSICS_H_INCLUDED
#define PHYSICS_H_INCLUDED


#include <cmath> 


namespace Physics 
{
	////////////////////////////
	// - Electricity Section - 
	////////////////////////////
	namespace Electricity
	{
	    double calculateCurrent(double charge, double time); 
		long double forceOnTwoCharges(const double q1, const double q2, int range) const;  
	}

	namespace Magnetism
	namespace Kinematics; 
	namespace Dynamics;
	namespace Energy; 
	namespace Sound; 
	namespace Optics; 
	namespace Astrophysics; 
}


#endif    // PHYSICS_H_INCLUDED 